#! /bin/sh -
#
# Each of the files t*.test is in two parts:
#
#     FILE=whistle-1.mp3
#     # Set an output file, and both add and replace a tag
#     OPTS='-e "TPE2=xxxxxxxx" -e TIT2=title -o out.mp3'
#     OUTFILE=out.mp3
#     ----
#     TPE1=Norman Gray
#     TPE2=xxxxxxxx
#     TIT2=title
#     8	209
#
# Above the '---' is a sequence of settings: FILE is the file to be
# acted upon, OPTS is the command-line arguments to mp3x, and OUTFILE,
# if present, is the file which is to be tested (it's the input file,
# presumably mutated, if this is missing).  Below the '----' is the
# result of 'mp3x -int' on the output file.  If the test should fail
# (that is, it should exit with an error status), then include
# MUSTERROR=1 to check that the program exit status is 1.


PROG=`cd ..;pwd`/mp3x

if test -d tmp; then rm -Rf tmp; fi
mkdir tmp
logfile=tmp/test-editing.log
rm -f $logfile
touch $logfile

ls for-editing/t*.test | while read f
do
    D=tmp/`expr $f : '.*/\(t.*\)\.test'`
    mkdir $D
    unset FILE OPTS OUTFILE MUSTERROR
    eval `sed -e '/^#/d' -e '/^--/,$d' $f`
    sed '1,/^--/d' $f >$D/correct
    cp for-editing/$FILE $D/t.mp3

    testfile=${OUTFILE:-t.mp3}

    (cd $D; echo "$PROG $OPTS t.mp3 2>stderr && $PROG -int $testfile >out" | sh)
    exitstatus=$?
    if test $exitstatus != 0; then
        if test -n "$MUSTERROR" -a $exitstatus = "$MUSTERROR"; then
            # that's OK
            rm -Rf $D
        else
            echo "FAIL: exited with error: output in $D/out" >$logfile
        fi
    elif diff $D/out $D/correct >$D/diff; then
        rm -Rf $D
    else
        echo "FAIL: diffs in $D/diff" >$logfile
        break # retain?
    fi
done

if test -s $logfile; then 
    echo "FAIL: some editing tests failed..."
    cat $logfile
    status=1
else
    #echo "All editing tests passed"
    rm -f $logfile
    status=0
fi

exit $status
